@@ -1,4 +1,4 @@
 package t::lib::D;
-use c3;    
+use Class::C3;    
 use base ('t::lib::A', 't::lib::E');
-1;
\ No newline at end of file
+1;
